==> openshift-model-operatorhub-6.6.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/NamedInstallStrategyFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NamedInstallStrategyFluentImpl<A extends NamedInstallStrategyFluent<A>> extends BaseFluent<A> implements NamedInstallStrategyFluent<A>{
  public NamedInstallStrategyFluentImpl() {
  }
  public NamedInstallStrategyFluentImpl(NamedInstallStrategy instance) {
    this.withSpec(instance.getSpec()); 
    this.withStrategy(instance.getStrategy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private StrategyDetailsDeploymentBuilder spec;
  private String strategy;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StrategyDetailsDeployment getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public StrategyDetailsDeployment buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StrategyDetailsDeployment spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StrategyDetailsDeploymentBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public NamedInstallStrategyFluent.SpecNested<A> withNewSpec() {
    return new NamedInstallStrategyFluentImpl.SpecNestedImpl();
  }
  public NamedInstallStrategyFluent.SpecNested<A> withNewSpecLike(StrategyDetailsDeployment item) {
    return new NamedInstallStrategyFluentImpl.SpecNestedImpl(item);
  }
  public NamedInstallStrategyFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public NamedInstallStrategyFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new StrategyDetailsDeploymentBuilder().build());
  }
  public NamedInstallStrategyFluent.SpecNested<A> editOrNewSpecLike(StrategyDetailsDeployment item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public String getStrategy() {
    return this.strategy;
  }
  public A withStrategy(String strategy) {
    this.strategy=strategy; return (A) this;
  }
  public Boolean hasStrategy() {
    return this.strategy != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamedInstallStrategyFluentImpl that = (NamedInstallStrategyFluentImpl) o;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (strategy != null ? !strategy.equals(that.strategy) :that.strategy != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(spec,  strategy,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (strategy != null) { sb.append("strategy:"); sb.append(strategy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class SpecNestedImpl<N> extends StrategyDetailsDeploymentFluentImpl<NamedInstallStrategyFluent.SpecNested<N>> implements NamedInstallStrategyFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(StrategyDetailsDeployment item) {
      this.builder = new StrategyDetailsDeploymentBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new StrategyDetailsDeploymentBuilder(this);
    }
    StrategyDetailsDeploymentBuilder builder;
    public N and() {
      return (N) NamedInstallStrategyFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-6.7.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/NamedInstallStrategyFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NamedInstallStrategyFluentImpl<A extends NamedInstallStrategyFluent<A>> extends BaseFluent<A> implements NamedInstallStrategyFluent<A>{
  public NamedInstallStrategyFluentImpl() {
  }
  public NamedInstallStrategyFluentImpl(NamedInstallStrategy instance) {
    if (instance != null) {
      this.withSpec(instance.getSpec());
      this.withStrategy(instance.getStrategy());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private StrategyDetailsDeploymentBuilder spec;
  private String strategy;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StrategyDetailsDeployment getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public StrategyDetailsDeployment buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StrategyDetailsDeployment spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StrategyDetailsDeploymentBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public NamedInstallStrategyFluentImpl.SpecNested<A> withNewSpec() {
    return new NamedInstallStrategyFluentImpl.SpecNestedImpl();
  }
  public NamedInstallStrategyFluentImpl.SpecNested<A> withNewSpecLike(StrategyDetailsDeployment item) {
    return new NamedInstallStrategyFluentImpl.SpecNestedImpl(item);
  }
  public NamedInstallStrategyFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public NamedInstallStrategyFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new StrategyDetailsDeploymentBuilder().build());
  }
  public NamedInstallStrategyFluentImpl.SpecNested<A> editOrNewSpecLike(StrategyDetailsDeployment item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public String getStrategy() {
    return this.strategy;
  }
  public A withStrategy(String strategy) {
    this.strategy=strategy; return (A) this;
  }
  public Boolean hasStrategy() {
    return this.strategy != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedInstallStrategyFluentImpl that = (NamedInstallStrategyFluentImpl) o;
    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(strategy, that.strategy)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(spec,  strategy,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (strategy != null) { sb.append("strategy:"); sb.append(strategy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class SpecNestedImpl<N> extends StrategyDetailsDeploymentFluentImpl<NamedInstallStrategyFluentImpl.SpecNested<N>> implements NamedInstallStrategyFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(StrategyDetailsDeployment item) {
      this.builder = new StrategyDetailsDeploymentBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new StrategyDetailsDeploymentBuilder(this);
    }
    StrategyDetailsDeploymentBuilder builder;
    public N and() {
      return (N) NamedInstallStrategyFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}
